Struct LineString

pub struct LineString<T: WktNum = f64> { /* private fields */ }
A parsed LineString.

Implementations

Source

impl<T: WktNum> LineString<T>

pub fn new(coords: Vec<Coord<T>>, dim: Dimension) -> Self

Create a new LineString from a sequence of Coord and known Dimension.

pub fn empty(dim: Dimension) -> Self

Create a new empty LineString.

pub fn from_coords(coords: impl IntoIterator<Item = Coord<T>>) -> Option<Self>

Create a new LineString from a non-empty sequence of Coord.

This will infer the dimension from the first coordinate, and will not validate that all coordinates have the same dimension.

Returns None if the input iterator is empty.

To handle empty input iterators, consider calling unwrap_or on the result and defaulting to an empty geometry with specified dimension.

pub fn dimension(&self) -> Dimension

Return the Dimension of this geometry.

pub fn coords(&self) -> &[Coord<T>]

Access the coordinates of this LineString.

pub fn into_inner(self) -> (Vec<Coord<T>>, Dimension)

Consume self and return the inner parts.