pub struct LineString<T: WktNum = f64> { /* private fields */ }Expand description
A parsed LineString.
Implementations
Sourceimpl<T: WktNum> LineString<T>
impl<T: WktNum> LineString<T>
Sourcepub fn from_coords(coords: impl IntoIterator<Item = Coord<T>>) -> Option<Self>
pub fn from_coords(coords: impl IntoIterator<Item = Coord<T>>) -> Option<Self>
Create a new LineString from a non-empty sequence of Coord.
This will infer the dimension from the first coordinate, and will not validate that all coordinates have the same dimension.
Returns None if the input iterator is empty.
To handle empty input iterators, consider calling unwrap_or on the result and defaulting
to an empty geometry with specified dimension.
Sourcepub fn into_inner(self) -> (Vec<Coord<T>>, Dimension)
pub fn into_inner(self) -> (Vec<Coord<T>>, Dimension)
Consume self and return the inner parts.